@@ -8,6 +8,7 @@ import requests
 import semantic_version
 from notebook.base.handlers import IPythonHandler
 from notebook.utils import url_path_join
+from notebook import notebookapp
 
 from jupyter_cogram import __version__
 
@@ -24,6 +25,7 @@ package_pypi_url = "https://pypi.org/pypi/jupyter-cogram/json"
 
 check_token_endpoint = "checkToken"
 
+logger.debug(f"Running jupyter-cogram version {__version__}")
 logger.debug(f"Backend URL: {backend_url}")
 logger.debug(f"Suggestions endpoint: {completions_enpdoint}")
 logger.debug(f"PyPI URL: {package_pypi_url}")
@@ -137,6 +139,10 @@ def fetch_suggestion_codex(
     return res.json()
 
 
+def upgrade():
+    pass
+
+
 class JupyterCogramHandler(IPythonHandler):
     def __init__(self, application, request, **kwargs):
         super(JupyterCogramHandler, self).__init__(application, request, **kwargs)
